@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "23" },
-            { "jdk", "23" },
-            { "release", "23" },
+            { "full", "24.0.1" },
+            { "jdk", "24.0.1" },
+            { "release", "24.0.1" },
         };
     }
 }
